﻿using System.Collections.Generic;
using System.Windows.Forms;

using DevExpress.XtraEditors;
using DevExpress.XtraEditors.Controls;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            List<Contact> sourceList = new List<Contact>();

            sourceList.Add(new Contact("John Doe"        ));
            sourceList.Add(new Contact("Sam Hill"        ));
            sourceList.Add(new Contact("Karen Holmes"    ));
            sourceList.Add(new Contact("Bobbie Valentine"));
            sourceList.Add(new Contact("Frank Frankson"  ));

            this.lookUpEdit.Properties.TextEditStyle = TextEditStyles.Standard;
            this.lookUpEdit.Properties.ValueMember   = "Name";              
            this.lookUpEdit.Properties.DisplayMember = "Name";
            this.lookUpEdit.Properties.DataSource    = sourceList;

            this.lookUpEdit.Properties.Columns.Add(new LookUpColumnInfo("Name", "Name", 80));

            this.lookUpEdit.ProcessNewValue += lookUpEdit_ProcessNewValue;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 룩업 에디터 신규 값 처리하기 - lookUpEdit_ProcessNewValue(sender, e)

        /// <summary>
        /// 룩업 에디터 신규 값 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void lookUpEdit_ProcessNewValue(object sender, ProcessNewValueEventArgs e)
        {
            string newValue = e.DisplayValue as string;

            if(string.IsNullOrWhiteSpace(newValue))
            {
                return;
            }

            DialogResult result = XtraMessageBox.Show
            (
                this,
                $"{newValue} 항목을 목록에 추가하시겠습니까?",
                "CONFIRMATION",
                MessageBoxButtons.YesNo,
                MessageBoxIcon.Question
            );

            if(result == DialogResult.Yes)
            {
                LookUpEdit lookUpEdit = sender as LookUpEdit;

                List<Contact> sourceList = lookUpEdit.Properties.DataSource as List<Contact>;

                sourceList.Add(new Contact(newValue));

                e.Handled = true;
            }
        }

        #endregion
    }
}